function VarTypeByte(
    table,      // Responsible TableOfVars instance
    varName     // Name of this variable
) {
    VarType.call(this, table, varName);
}
VarTypeByte.prototype = Object.create(VarType.prototype);
VarTypeByte.prototype.constructor = VarTypeByte;

/** Add to list of available types */
TableOfVars.varTypes.push(VarTypeByte);

/** Name of variable type */
VarTypeByte.typeName = 'byte';
VarTypeByte.prototype.typeName = 'byte';

/** Used number of bytes to store this variable */
VarTypeByte.countBytes = 1;

/** Default value of variables of this type */
VarTypeByte.defaultValue = 0;

/** Minimum and maximum allowed value */
VarTypeByte.prototype.minValue = -128;
VarTypeByte.prototype.maxValue = 127;

/** Present value */
Object.defineProperty(VarTypeByte.prototype, 'value', { enumerable: true,
    get() { return +this.input.value; },
    set(v) {
        if (!Number.isInteger(v))
            return;
        const statecount = this.maxValue - this.minValue + 1;
        this.input.value = (statecount + (v - this.minValue) % statecount) % statecount + this.minValue;
    }
});

/**
* Create a input for this type
* @return HTMLElement       Created input, select, …
*/
VarTypeByte.prototype._createInput = function(
    document        // HTMLDocument instance to use
) {
    const input = document.createElement('input');
    input.type = 'number';
    input.value = VarTypeByte.defaultValue;
    input.step = 1;
    input.min = this.minValue;
    input.max = this.maxValue;
    return input;
}
